import { AdapterBase } from '@feathersjs/adapter-commons';
import type { PaginationOptions } from '@feathersjs/adapter-commons';
import type { SequelizeAdapterOptions, SequelizeAdapterParams } from './declarations';
import type { Id, NullableId, Paginated, Query } from '@feathersjs/feathers';
import type { FindOptions } from 'sequelize';
export declare class SequelizeAdapter<T, D = Partial<T>, P extends SequelizeAdapterParams = SequelizeAdapterParams> extends AdapterBase<T, D, P, SequelizeAdapterOptions> {
    constructor(options: SequelizeAdapterOptions);
    get raw(): boolean;
    get Op(): any;
    get Model(): import("sequelize").ModelStatic<any>;
    getModel(_params?: P): import("sequelize").ModelStatic<any>;
    /**
     * @deprecated use 'service.ModelWithScope' instead. 'applyScope' will be removed in a future release.
     */
    applyScope(params?: P): import("sequelize").ModelStatic<any> | import("sequelize").ModelCtor<any>;
    ModelWithScope(params: P): import("sequelize").ModelStatic<any> | import("sequelize").ModelCtor<any>;
    convertOperators(q: any): Query;
    filterQuery(params: P): {
        filters: {
            [key: string]: any;
        };
        query: Query;
        paginate: import("@feathersjs/adapter-commons").PaginationParams;
    };
    paramsToAdapter(id: NullableId, _params?: P): FindOptions;
    /**
     * returns either the model instance / jsonified object for an id or all unpaginated
     * items for `params` if id is null
     */
    _getOrFind(id: Id, _params?: P): Promise<T>;
    _getOrFind(id: null, _params?: P): Promise<T[]>;
    $find(params?: P & {
        paginate?: PaginationOptions;
    }): Promise<Paginated<T>>;
    $find(params?: P & {
        paginate: false;
    }): Promise<T[]>;
    $find(params?: P): Promise<Paginated<T> | T[]>;
    $get(id: Id, params?: P): Promise<T>;
    $create(data: Partial<D>, params?: P): Promise<T>;
    $create(data: Partial<D>[], params?: P): Promise<T[]>;
    $create(data: Partial<D> | Partial<D>[], _params?: P): Promise<T | T[]>;
    $patch(id: null, data: Partial<D>, params?: P): Promise<T[]>;
    $patch(id: Id, data: Partial<D>, params?: P): Promise<T>;
    $patch(id: NullableId, data: Partial<D>, _params?: P): Promise<T | T[]>;
    $update(id: Id, data: D, params?: P): Promise<T>;
    $remove(id: null, params?: P): Promise<T[]>;
    $remove(id: Id, params?: P): Promise<T>;
    $remove(id: NullableId, params?: P): Promise<T | T[]>;
}
